@@ -335,7 +335,7 @@ class LogManager(object):
 
 @lru_cache() # LogManager 本身也支持无限实例化
 def get_logger(name: str, *, log_level_int: int = None, is_add_stream_handler=True,
-               do_not_use_color_handler=None, log_path='/pythonlogs',
+               do_not_use_color_handler=None, log_path=None,
                log_filename=None, log_file_size: int = None,
                mongo_url=None, is_add_elastic_handler=False, is_add_kafka_handler=False,
                ding_talk_token=None, ding_talk_time_interval=60,
